@@ -20,6 +20,7 @@ from abc import ABCMeta, abstractmethod
 from collections.abc import AsyncIterable, Awaitable, Iterable
 from dataclasses import dataclass
 from datetime import timedelta
+from enum import Enum
 import logging
 from typing import Any, Callable, TypedDict, final
 
@@ -39,7 +40,6 @@ logger = logging.getLogger(__name__)
 
 
 class AbstractPairingData(TypedDict, total=False):
-
     AccessoryPairingID: str
     AccessoryLTPK: str
     iOSPairingId: str
@@ -51,7 +51,6 @@ class AbstractPairingData(TypedDict, total=False):
 
 @dataclass
 class AbstractDescription:
-
     name: str
     id: str
     status_flags: StatusFlags
@@ -59,8 +58,13 @@ class AbstractDescription:
     category: Categories
 
 
-class AbstractPairing(metaclass=ABCMeta):
+class TransportType(Enum):
+    IP = "ip"
+    COAP = "coap"
+    BLE = "ble"
 
+
+class AbstractPairing(metaclass=ABCMeta):
     # The current discovery information for this pairing.
     # This can be used to detect address changes, s# changes, c# changes, etc
     description: AbstractDescription | None = None
@@ -267,6 +271,13 @@ class AbstractPairing(metaclass=ABCMeta):
         )
         return accessory_info.value(CharacteristicsTypes.NAME, "")
 
+    @abstractmethod
+    async def thread_provision(
+        self,
+        dataset: str,
+    ) -> None:
+        """Provision a device with Thread network credentials."""
+
     @abstractmethod
     async def async_populate_accessories_state(
         self, force_update: bool = False, attempts: int | None = None
@@ -402,7 +413,6 @@ FinishPairing = Callable[[str], Awaitable[AbstractPairing]]
 
 
 class AbstractDiscovery(metaclass=ABCMeta):
-
     description: AbstractDescription
 
     @final
@@ -420,7 +430,6 @@ class AbstractDiscovery(metaclass=ABCMeta):
 
 
 class AbstractController(metaclass=ABCMeta):
-
     discoveries: dict[str, AbstractDiscovery]
     pairings: dict[str, AbstractPairing]
     aliases: dict[str, AbstractPairing]
@@ -432,6 +441,10 @@ class AbstractController(metaclass=ABCMeta):
 
         self._char_cache = char_cache
 
+    @property
+    def transport_type(self) -> TransportType:
+        raise NotImplementedError(self.transport_type)
+
     @final
     async def __aenter__(self):
         await self.async_start()
