@@ -10,7 +10,11 @@ from bleak.backends.scanner import AdvertisementData
 from bleak.exc import BleakDBusError, BleakError
 
 from aiohomekit.characteristic_cache import CharacteristicCacheType
-from aiohomekit.controller.abstract import AbstractController, AbstractPairingData
+from aiohomekit.controller.abstract import (
+    AbstractController,
+    AbstractPairingData,
+    TransportType,
+)
 from aiohomekit.controller.ble.manufacturer_data import (
     APPLE_MANUFACTURER_ID,
     HOMEKIT_ADVERTISEMENT_TYPE,
@@ -19,6 +23,7 @@ from aiohomekit.controller.ble.manufacturer_data import (
     HomeKitEncryptedNotification,
 )
 from aiohomekit.controller.ble.pairing import BlePairing
+from aiohomekit.exceptions import AccessoryNotFoundError
 from aiohomekit.utils import asyncio_timeout
 
 from .discovery import BleDiscovery
@@ -30,6 +35,7 @@ class BleController(AbstractController):
     discoveries: dict[str, BleDiscovery]
     pairings: dict[str, BlePairing]
     aliases: dict[str, BlePairing]
+    transport_type = TransportType.BLE
 
     _scanner: BleakScanner | None
 
@@ -41,7 +47,6 @@ class BleController(AbstractController):
         super().__init__(char_cache=char_cache)
         self._scanner = bleak_scanner_instance
         self._ble_futures: dict[str, list[asyncio.Future[BLEDevice]]] = {}
-        self._ble_futures_by_id: dict[str, list[asyncio.Future[BLEDevice]]] = {}
 
     def _device_detected(
         self, device: BLEDevice, advertisement_data: AdvertisementData
@@ -73,11 +78,13 @@ class BleController(AbstractController):
         except ValueError:
             return
 
-        if pairing := self.pairings.get(data.id):
-            if (
-                (old_description := pairing.description)
-                and old_description.name != old_description.address
-                and len(old_description.name) > len(data.name)
+        if old_discovery := self.discoveries.get(data.id):
+            if (old_name := old_discovery.description.name) and (
+                not (name := data.name)
+                or (
+                    old_name != old_discovery.device.address
+                    and len(old_name) > len(name)
+                )
             ):
                 #
                 # If we have a pairing and the name is longer than the one we
@@ -90,30 +97,23 @@ class BleController(AbstractController):
                 # shall not be used to advertise a name that is longer than the
                 # Local Name data type.
                 #
-                data.name = old_description.name
+                data.name = old_name
+
+        if pairing := self.pairings.get(data.id):
             pairing._async_description_update(data)
             pairing._async_ble_update(device, advertisement_data)
 
-        if futures := self._ble_futures_by_id.get(data.id):
+        if futures := self._ble_futures.get(data.id):
             discovery = BleDiscovery(self, device, data, advertisement_data)
             logger.debug("BLE device for %s found, fulfilling futures", data.id)
             for future in futures:
                 future.set_result(discovery)
             futures.clear()
 
-        if futures := self._ble_futures.get(data.address):
-            discovery = BleDiscovery(self, device, data, advertisement_data)
-            logger.debug("BLE device for %s found, fulfilling futures", data.address)
-            for future in futures:
-                future.set_result(discovery)
-            futures.clear()
-
-        if data.id in self.discoveries:
+        if old_discovery:
             # We need to make sure we update the device details
             # in case they changed
-            self.discoveries[data.id]._async_process_advertisement(
-                device, data, advertisement_data
-            )
+            old_discovery._async_process_advertisement(device, data, advertisement_data)
             return
 
         self.discoveries[data.id] = BleDiscovery(self, device, data, advertisement_data)
@@ -153,8 +153,7 @@ class BleController(AbstractController):
             device_id,
             timeout,
         )
-        future = asyncio.Future()
-        self._ble_futures_by_id.setdefault(device_id, []).append(future)
+        future = asyncio.get_running_loop().create_future()
         try:
             async with asyncio_timeout(timeout):
                 return await future
@@ -164,52 +163,21 @@ class BleController(AbstractController):
                 timeout,
                 device_id,
             )
-            return None
+            raise AccessoryNotFoundError(
+                f"Accessory with device id {device_id} not found"
+            )
         finally:
-            if device_id not in self._ble_futures_by_id:
+            if device_id not in self._ble_futures:
                 return
-            if future in self._ble_futures_by_id[device_id]:
-                self._ble_futures_by_id[device_id].remove(future)
-            if not self._ble_futures_by_id[device_id]:
-                del self._ble_futures_by_id[device_id]
+            if future in self._ble_futures[device_id]:
+                self._ble_futures[device_id].remove(future)
+            if not self._ble_futures[device_id]:
+                del self._ble_futures[device_id]
 
     async def async_discover(self) -> AsyncIterable[BleDiscovery]:
         for device in self.discoveries.values():
             yield device
 
-    async def async_get_discovery(
-        self, address: str, timeout: int
-    ) -> BleDiscovery | None:
-        """Get a discovery by address."""
-        if discovery := self.discoveries.get(address):
-            logger.debug("Discovery for %s already found", address)
-            return discovery
-
-        logger.debug(
-            "Discovery for address %s not found, waiting for advertisement with timeout: %s",
-            address,
-            timeout,
-        )
-        future = asyncio.Future()
-        self._ble_futures.setdefault(address, []).append(future)
-        try:
-            async with asyncio_timeout(timeout):
-                return await future
-        except asyncio.TimeoutError:
-            logger.debug(
-                "Timed out after %s waiting for discovery with address %s",
-                timeout,
-                address,
-            )
-            return None
-        finally:
-            if address not in self._ble_futures:
-                return
-            if future in self._ble_futures[address]:
-                self._ble_futures[address].remove(future)
-            if not self._ble_futures[address]:
-                del self._ble_futures[address]
-
     def load_pairing(
         self, alias: str, pairing_data: AbstractPairingData
     ) -> BlePairing | None:
