@@ -66,7 +66,6 @@ def decode_list_pairings_response(buf):
 
 
 class EncryptionContext:
-
     coap_ctx: Context
     lock: asyncio.Lock
     uri: str
@@ -207,7 +206,7 @@ class EventResource(resource.Resource):
         try:
             payload = self.connection.enc_ctx.decrypt_event(request.payload)
         except InvalidTag:
-            logger.warning(
+            logger.debug(
                 "Event decryption failed, desynchronized? Counter=%d"
                 % (self.connection.enc_ctx.event_ctr,)
             )
@@ -295,7 +294,7 @@ class CoAPHomeKitConnection:
                 salt, srpB = result.value
                 return salt, srpB
             except Exception:
-                logger.warning("Pair setup 1/2 failed!")
+                logger.debug("Pair setup 1/2 failed!")
                 await self.pair_setup_client.shutdown()
                 raise
 
@@ -319,7 +318,7 @@ class CoAPHomeKitConnection:
                 pairing = result.value
                 break
             except Exception:
-                logger.warning("Pair setup 2/2 failed!")
+                logger.debug("Pair setup 2/2 failed!")
                 await self.pair_setup_client.shutdown()
                 raise
 
@@ -331,7 +330,7 @@ class CoAPHomeKitConnection:
 
     async def do_pair_verify(self, pairing_data):
         if self.is_connected:
-            logger.warning("Connecting to connected device?")
+            logger.debug("Connecting to connected device?")
             await self.enc_ctx.coap_ctx.shutdown()
             self.enc_ctx = None
 
@@ -390,10 +389,10 @@ class CoAPHomeKitConnection:
             try:
                 await self.do_pair_verify(pairing_data)
             except asyncio.TimeoutError:
-                logger.warning("Pair verify timed out")
+                logger.debug("Pair verify timed out")
                 raise AccessoryDisconnectedError("Pair verify timed out")
             except Exception as exc:
-                logger.warning("Pair verify failed", exc_info=exc)
+                logger.debug("Pair verify failed", exc_info=exc)
                 raise AccessoryDisconnectedError("Pair verify failed")
 
             # we need the info this provides to be able to read/write characteristics
@@ -435,7 +434,7 @@ class CoAPHomeKitConnection:
                 # send the read requests
                 results = await self.enc_ctx.post_all(OpCode.CHAR_READ, iids, data)
 
-                for (idx, result) in enumerate(results):
+                for idx, result in enumerate(results):
                     if isinstance(result, bytes):
                         # success, let's convert the value
                         value = decode_pdu_03(result) if len(result) > 0 else b""
@@ -466,7 +465,7 @@ class CoAPHomeKitConnection:
         self, ids: list[tuple[int, int]], pdu_results: list[bytes | PDUStatus]
     ) -> dict:
         results = dict()
-        for (idx, result) in enumerate(pdu_results):
+        for idx, result in enumerate(pdu_results):
             aid_iid = ids[idx]
             if isinstance(result, PDUStatus):
                 logger.debug(
@@ -514,7 +513,7 @@ class CoAPHomeKitConnection:
     ) -> list[bytearray]:
         # convert provided values to appropriate binary format for each characteristic
         tlv_values = list()
-        for (_, aid_iid_value) in enumerate(ids_values):
+        for _, aid_iid_value in enumerate(ids_values):
             # look up characteristic
             characteristic = self.info.find_characteristic_by_aid_iid(
                 int(aid_iid_value[0]), int(aid_iid_value[1])
@@ -538,7 +537,7 @@ class CoAPHomeKitConnection:
         # transform results
         # only error conditions are returned
         results = dict()
-        for (idx, result) in enumerate(pdu_results):
+        for idx, result in enumerate(pdu_results):
             aid_iid_value = ids_values[idx]
             key = (aid_iid_value[0], aid_iid_value[1])
             if isinstance(result, PDUStatus):
@@ -573,7 +572,7 @@ class CoAPHomeKitConnection:
         self, ids: list[tuple[int, int]], pdu_results: list[bytes | PDUStatus]
     ) -> dict:
         results = dict()
-        for (idx, result) in enumerate(pdu_results):
+        for idx, result in enumerate(pdu_results):
             aid_iid = ids[idx]
             key = (aid_iid[0], aid_iid[1])
             if isinstance(result, PDUStatus):
@@ -602,7 +601,7 @@ class CoAPHomeKitConnection:
         self, ids: list[tuple[int, int]], pdu_results: list[bytes | PDUStatus]
     ) -> dict:
         results = dict()
-        for (idx, result) in enumerate(pdu_results):
+        for idx, result in enumerate(pdu_results):
             aid_iid = ids[idx]
             key = (aid_iid[0], aid_iid[1])
             if isinstance(result, PDUStatus):
@@ -661,14 +660,12 @@ class CoAPHomeKitConnection:
 
         m2_state = list(filter(lambda x: x[0] == TLV.kTLVType_State, m2))
         if len(m2_state) != 1 or m2_state[0][1] != TLV.M2:
-            logger.warning("Unexpected state in list pairings M2")
+            logger.debug("Unexpected state in list pairings M2")
             return
 
         m2_error = list(filter(lambda x: x[0] == TLV.kTLVType_Error, m2))
         if len(m2_error) != 0:
-            logger.warning(
-                f"Error from accessory during list pairings: {m2_error[0][1]}"
-            )
+            logger.debug(f"Error from accessory during list pairings: {m2_error[0][1]}")
             return
 
         id_list = [
