@@ -54,7 +54,6 @@ NEEDS_POLLINGS_CHARS = {
 
 
 class Transport(Enum):
-
     BLE = "ble"
     COAP = "coap"
     IP = "ip"
@@ -160,11 +159,13 @@ class Characteristics:
 
 
 class Accessory:
-    def __init__(self):
+    def __init__(self) -> None:
+        """Initialize a new accessory."""
         self.aid = get_id()
         self._next_id = 0
         self.services = Services()
         self.characteristics = Characteristics(self.services)
+        self._accessory_information: Service | None = None
 
     @classmethod
     def create_with_info(
@@ -197,7 +198,11 @@ class Accessory:
     @property
     def accessory_information(self) -> Service:
         """Returns the ACCESSORY_INFORMATION service for this accessory."""
-        return self.services.first(service_type=ServicesTypes.ACCESSORY_INFORMATION)
+        if self._accessory_information is None:
+            self._accessory_information = self.services.first(
+                service_type=ServicesTypes.ACCESSORY_INFORMATION
+            )
+        return self._accessory_information
 
     @property
     def name(self) -> str:
@@ -320,7 +325,6 @@ class Accessory:
 
 
 class Accessories:
-
     accessories: list[Accessory]
 
     def __init__(self) -> None:
@@ -366,7 +370,7 @@ class Accessories:
         return aid in self._aid_to_accessory
 
     def process_changes(self, changes: dict[tuple[int, int], Any]) -> None:
-        for ((aid, iid), value) in changes.items():
+        for (aid, iid), value in changes.items():
             accessory = self.aid(aid)
             if not accessory:
                 continue
@@ -383,7 +387,6 @@ class Accessories:
 
 @dataclass
 class AccessoriesState:
-
     accessories: Accessories
     config_num: int
     broadcast_key: bytes | None = None
